@@ -4,7 +4,7 @@
  * This file contains some tuneable parameters, most of which can be overriden
  * at run-time (note, MAX_CONNECTIONS can't!).
  *
- * $Id: defaults.h,v 1.2 1999/12/17 18:57:30 patl Exp $
+ * $Id: defaults.h,v 1.6 2004/04/28 11:36:07 quozl Exp $
  */
 
 #ifndef _PPTPD_DEFAULTS_H
@@ -35,31 +35,43 @@
 #define DEFAULT_REMOTE_IP_LIST		"192.168.1.1-100"
 #endif
 
+#define MAX_CALLS_PER_TCP_LINK		128
+
 #ifdef PNS_MODE
 #define MAX_CALLS			60
 #endif
 
 #define PPP_SPEED_DEFAULT		"115200"
+#if EMBED
+#define PPTPD_CONFIG_FILE_DEFAULT	"/etc/config/pptpd.conf"
+#else
 #define PPTPD_CONFIG_FILE_DEFAULT	"/etc/pptpd.conf"
+#endif
 #define PIDFILE_DEFAULT			"/var/run/pptpd.pid"
 
+#define STIMEOUT_DEFAULT		10 /* seconds */
+
 /* Location of binaries */
 
 #define PPTP_CTRL_BIN			SBINDIR "/pptpctrl"
 #define PPTPD_BIN			SBINDIR "/pptpd"
+#define BCRELAY_BIN			SBINDIR "/bcrelay"
 
 /* Parameters permitted in the config file */
 
 #define SPEED_KEYWORD			"speed"
 #define PPPD_OPTION_KEYWORD		"option"
 #define DEBUG_KEYWORD			"debug"
+#ifdef BCRELAY
+#define BCRELAY_KEYWORD			"bcrelay"
+#endif
 #define LOCALIP_KEYWORD			"localip"
 #define REMOTEIP_KEYWORD		"remoteip"
-#define IPXNETS_KEYWORD			"ipxnets"
 #define LISTEN_KEYWORD			"listen"
 #define PIDFILE_KEYWORD			"pidfile"
-
-/* Logging facility */
-#define LOG_PPTP                        LOG_LOCAL2
+#define STIMEOUT_KEYWORD		"stimeout"
+#define NOIPPARAM_KEYWORD		"noipparam"
+#define PPP_BINARY_KEYWORD		"ppp"
+#define LOGWTMP_KEYWORD			"logwtmp"
 
 #endif	/* !_PPTPD_DEFAULTS_H */
