@@ -1,5 +1,5 @@
 /*
- * $Id: pptpd-logwtmp.c,v 1.2 2004/04/29 09:54:01 quozl Exp $
+ * $Id: pptpd-logwtmp.c,v 1.3 2005/08/02 09:51:18 quozl Exp $
  * pptpd-logwtmp.c - pppd plugin to update wtmp for a pptpd user
  *
  * Copyright 2004 James Cameron.
@@ -16,20 +16,29 @@
 char pppd_version[] = VERSION;
 
 static char pptpd_original_ip[PATH_MAX+1];
+static bool pptpd_logwtmp_strip_domain = 0;
 
 static option_t options[] = {
   { "pptpd-original-ip", o_string, pptpd_original_ip,
     "Original IP address of the PPTP connection",
     OPT_STATIC, NULL, PATH_MAX },
+  { "pptpd-logwtmp-strip-domain", o_bool, &pptpd_logwtmp_strip_domain,
+    "Strip domain from username before logging", OPT_PRIO | 1 },
   { NULL }
 };
 
 static void ip_up(void *opaque, int arg)
 {
+  char *user = peer_authname;
+  if (pptpd_logwtmp_strip_domain) {
+    char *sep = strstr(user, "//");
+    if (sep != NULL)
+      user = sep + 2;
+  }
   if (debug)
-    notice("pptpd-logwtmp.so ip-up %s %s %s", ifname, peer_authname, 
+    notice("pptpd-logwtmp.so ip-up %s %s %s", ifname, user, 
 	   pptpd_original_ip);
-  logwtmp(ifname, peer_authname, pptpd_original_ip);
+  logwtmp(ifname, user, pptpd_original_ip);
 }
 
 static void ip_down(void *opaque, int arg)
