@@ -3,7 +3,7 @@
  *
  * PPTP control connection between PAC-PNS pair
  *
- * $Id: pptpctrl.c,v 1.13 2004/04/28 11:36:07 quozl Exp $
+ * $Id: pptpctrl.c,v 1.18 2005/07/29 13:00:40 quozl Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -118,7 +118,7 @@ int main(int argc, char **argv)
 	}
 
 	/* open a connection to the syslog daemon */
-	openlog("pptpd", LOG_PID, LOG_DAEMON);
+	openlog("pptpd", LOG_PID, PPTP_FACILITY);
 
 	/* autoreap if supported */
 	signal(SIGCHLD, SIG_IGN);
@@ -180,7 +180,8 @@ int main(int argc, char **argv)
             inet_ntoa(addr.sin_addr), ' ');
 
 	/* be ready for a grisly death */
-	signal(SIGTERM, &bail);
+	sigpipe_create();
+	sigpipe_assign(SIGTERM);
 	NOTE_VALUE(PAC, call_id_pair, htons(-1));
 	NOTE_VALUE(PNS, call_id_pair, htons(-1));
 
@@ -233,6 +234,7 @@ static void pptp_handle_ctrl_connection(char **pppaddrs, struct in_addr *inetadd
 #endif
 	int pty_fd = -1;		/* File descriptor of pty */
 	int gre_fd = -1;		/* Network file descriptor */
+	int sig_fd = sigpipe_fd();	/* Signal pipe descriptor	*/
 
 	unsigned char packet[PPTP_MAX_CTRL_PCKT_SIZE];
 	unsigned char rply_packet[PPTP_MAX_CTRL_PCKT_SIZE];
@@ -240,6 +242,7 @@ static void pptp_handle_ctrl_connection(char **pppaddrs, struct in_addr *inetadd
 	for (;;) {
 
 		FD_ZERO(&fds);
+		FD_SET(sig_fd, &fds);
 		FD_SET(clientSocket, &fds);
 		if (pty_fd != -1)
 			FD_SET(pty_fd, &fds);
@@ -287,6 +290,12 @@ static void pptp_handle_ctrl_connection(char **pppaddrs, struct in_addr *inetadd
 			break;
 		}
 
+		/* check for pending SIGTERM delivery */
+		if (FD_ISSET(sig_fd, &fds)) {
+			if (sigpipe_read() == SIGTERM)
+				bail(SIGTERM);
+		}
+
 		/* detect startup of pppd */
 #ifndef init
 		if (!init && pty_fd != -1 && FD_ISSET(pty_fd, &fds))
@@ -365,18 +374,37 @@ static void pptp_handle_ctrl_connection(char **pppaddrs, struct in_addr *inetadd
 						pty_fd = -1;
 					}
 				}
-				/* Start the call */
-				syslog(LOG_INFO, "CTRL: Starting call (launching pppd, opening GRE)");
-
-                                /* Fiddle with argv */
+                                /* change process title for accounting and status scripts */
                                 my_setproctitle(gargc, gargv,
                                       "pptpd [%s:%04X - %04X]",
                                       inet_ntoa(inetaddrs[1]),
                                       ntohs(((struct pptp_out_call_rply *) (rply_packet))->call_id_peer),
                                       ntohs(((struct pptp_out_call_rply *) (rply_packet))->call_id));
-
-				if ((pty_fd = startCall(pppaddrs, inetaddrs)) > maxfd)
-					maxfd = pty_fd;
+				/* start the call, by launching pppd */
+				syslog(LOG_INFO, "CTRL: Starting call (launching pppd, opening GRE)");
+				pty_fd = startCall(pppaddrs, inetaddrs);
+				if (pty_fd > maxfd) maxfd = pty_fd;
+				/* wait for first packet from ppp before proceeding, thus
+				   delaying outgoing call reply, and avoiding traffic 
+				   injection into the pty before echo has been turned off
+				   by pppd */
+				if (PPP_WAIT) {
+					fd_set pty_fds;
+					FD_ZERO(&pty_fds);
+					FD_SET(pty_fd, &pty_fds);
+					idleTime.tv_sec = PPP_WAIT;
+					idleTime.tv_usec = 0;
+					switch (select(maxfd + 1, &pty_fds, NULL, NULL, &idleTime)) {
+					case -1:
+						syslog(LOG_ERR, 
+						       "CTRL: pty select() failed, ignoring");
+						break;
+					case 0:
+						syslog(LOG_ERR, 
+						       "CTRL: timeout waiting for first packet from our pppd");
+						break;
+					}
+				}
 				if ((gre_fd = pptp_gre_init(call_id_pair, pty_fd, inetaddrs)) > maxfd)
 					maxfd = gre_fd;
 				break;
@@ -451,7 +479,7 @@ leave_clear_call:
 static void bail(int sigraised)
 {
 	if (sigraised)
-		syslog(LOG_INFO, "CTRL: Exiting on signal");
+		syslog(LOG_INFO, "CTRL: Exiting on signal %d", sigraised);
 
 	/* send a disconnect to the other end */
 	/* ignore any errors */
@@ -575,8 +603,16 @@ static int startCall(char **pppaddrs, struct in_addr *inetaddrs)
 		_exit(1);
 
 	case 0:		/* child */
-		dup2(tty_fd, 0);
-		dup2(tty_fd, 1);
+		if (dup2(tty_fd, 0) == -1) {
+		  syslog(LOG_ERR, "CTRL: child tty_fd dup2 to stdin, %s",
+			 strerror(errno));
+		  exit(1);
+		}
+		if (dup2(tty_fd, 1) == -1) {
+		  syslog(LOG_ERR, "CTRL: child tty_fd dup2 to stdout, %s",
+			 strerror(errno));
+		  exit(1);
+		}
 #if 0
 		/* This must never be used if !HAVE_SYSLOG since that logs to stderr.
 		 * Trying just never using it to see if it causes anyone else problems.
