@@ -4,7 +4,7 @@
  * Grabs any command line argument and processes any further options in
  * the pptpd config file, before throwing over to pptpmanager.c.
  *
- * $Id: pptpd.c,v 1.11 2004/05/17 06:32:00 quozl Exp $
+ * $Id: pptpd.c,v 1.15 2005/02/17 02:04:59 quozl Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -84,14 +84,12 @@ static char *lookup(char *);
 
 #ifdef BCRELAY
 static void launch_bcrelay();
-static void killbcrelay(int sigraised);
 static pid_t bcrelayfork;
 #endif
 
 static void showusage(char *prog)
 {
-	printf("\nPoptop v%s\n", VERSION);
-	printf("The PPTP Server for Linux\n");
+	printf("\npptpd v%s\n", VERSION);
 	printf("Usage: pptpd [options], where options are:\n\n");
 #ifdef BCRELAY
 	printf(" [-b] [--bcrelay if]       Use broadcast relay for broadcasts comming from.\n");
@@ -118,7 +116,7 @@ static void showusage(char *prog)
 #endif
 	printf(" [-t] [--stimeout seconds] Specifies the timeout for the first packet. This is a DOS protection\n");
 	printf("                           (default is 10).\n");
-	printf(" [-v] [--version]          Displays the PoPToP version number.\n");
+	printf(" [-v] [--version]          Displays the pptpd version number.\n");
 	printf(" [-w] [--logwtmp]          Update wtmp as users login.\n");
 
 	printf("\n\nLogs and debugging go to syslog as DAEMON.");
@@ -130,7 +128,7 @@ static void showusage(char *prog)
 
 static void showversion()
 {
-	printf("Poptop v%s\n", VERSION);
+	printf("pptpd v%s\n", VERSION);
 }
 
 int main(int argc, char **argv)
@@ -149,7 +147,7 @@ int main(int argc, char **argv)
 	char tmp[MAX_CONFIG_STRING_SIZE], *tmpstr;
 
 	/* open a connection to the syslog daemon */
-	openlog("pptpd", LOG_PID, LOG_DAEMON);
+	openlog("pptpd", LOG_PID, PPTP_FACILITY);
 
 	/* process command line options */
 	while (1) {
@@ -380,7 +378,7 @@ int main(int argc, char **argv)
 		daemon(0, 0);
 		/* returns to child only */
 		/* pid will have changed */
-		openlog("pptpd", LOG_PID, LOG_DAEMON);
+		openlog("pptpd", LOG_PID, PPTP_FACILITY);
 #else	/* !HAVE_DAEMON */
 		my_daemon(argc, argv);
 		/* returns to child if !HAVE_FORK
@@ -418,28 +416,20 @@ int main(int argc, char **argv)
 	/* after we have our final pid... */
 	log_pid(pid_file);
 
-#ifdef BCRELAY
-        /* be ready for a grisly death */
-        signal(SIGTERM, &killbcrelay);
-#endif
-
+	/* manage connections until SIGTERM */
 	pptp_manager(argc, argv);
+	
+#ifdef BCRELAY
+	if (bcrelayfork > 0) {
+		syslog(LOG_DEBUG, "CTRL: Closing child BCrelay with pid %i", bcrelayfork);
+		kill(bcrelayfork, SIGTERM);
+	}
+#endif
 
         return 1;
 
 }
 
-#ifdef BCRELAY
-static void killbcrelay(int sigraised) {
-        if (sigraised) {
-                syslog(LOG_DEBUG, "CTRL: Closing child BCrelay with pid %i", bcrelayfork);
-                if (bcrelayfork > 0)
-                kill(bcrelayfork, SIGQUIT);
-		exit(0);
-        }
-}
-#endif
-
 static void log_pid(char *pid_file) {
         FILE    *f;
         pid_t   pid;
@@ -498,7 +488,7 @@ static void my_daemon(int argc, char **argv)
 	chdir("/");
 	umask(0);
 	/* pid will have changed */
-	openlog("pptpd", LOG_PID, LOG_DAEMON);
+	openlog("pptpd", LOG_PID, PPTP_FACILITY);
 #endif
 }
 #endif
