@@ -3,7 +3,7 @@
  *
  * PPTP structs and defines
  *
- * $Id: pptpdefs.h,v 1.2 1999/12/23 21:43:33 patl Exp $
+ * $Id: pptpdefs.h,v 1.3 2005/08/02 09:51:18 quozl Exp $
  */
 
 #ifndef _PPTPD_PPTPDEFS_H
@@ -30,8 +30,8 @@
 #define	PPTP_FIRMWARE_VERSION		0x0001
 
 /* Hostname and Vendor */
-#define PPTP_HOSTNAME			{'l','o','c','a','l',0}
-#define PPTP_VENDOR			{'M','o','r','e','t','o','n','B','a','y',0}
+#define PPTP_HOSTNAME			"local"
+#define PPTP_VENDOR			"linux"
 
 #define MAX_HOSTNAME_SIZE		64
 #define MAX_VENDOR_SIZE			64
@@ -69,10 +69,13 @@
 #define SET_LINK_INFO			15
 
 /* how long before a link is idle? (seconds) */
-#define IDLE_WAIT			65
+#define IDLE_WAIT			60
 
 /* how long should we wait for an echo reply? (seconds) */
-#define MAX_ECHO_WAIT			5
+#define MAX_ECHO_WAIT			60
+
+/* how long to wait for ppp to begin negotiation (seconds) */
+#define PPP_WAIT			10
 
 #define RESERVED			0x0000
 
@@ -90,7 +93,7 @@
 #define MAX_CHANNELS			0x0001
 
 /* Out Call Reply Defines */
-#define PCKT_RECV_WINDOW_SIZE		32
+#define PCKT_RECV_WINDOW_SIZE		0x0001
 #define PCKT_PROCESS_DELAY		0x0000
 #define CHANNEL_ID			0x00000000
 
@@ -306,6 +309,9 @@ struct pptp_gre_header {
 	u_int16_t protocol;	/* should be PPTP_GRE_PROTO (ppp-encaps) */
 	u_int16_t payload_len;	/* size of ppp payload, not inc. gre header */
 	u_int16_t call_id;	/* peer's call_id for this session */
+	u_int32_t seq;		/* sequence number.  Present if S==1 */
+	u_int32_t ack;		/* seq number of highest packet recieved by */
+	/* sender in this session */
 };
 
 /* For our call ID pairs */
